@@ -2,7 +2,6 @@
 Contains Marktlokation class
 and corresponding marshmallow schema for de-/serialization
 """
-import re
 
 import attr
 from marshmallow import fields
@@ -22,8 +21,7 @@ from bo4e.enum.gebiettyp import Gebiettyp
 from bo4e.enum.netzebene import Netzebene
 from bo4e.enum.sparte import Sparte
 from bo4e.enum.verbrauchsart import Verbrauchsart
-
-_malo_id_pattern = re.compile(r"^[1-9][\d]{10}$")
+from bo4e.validators import validate_marktlokations_id
 
 
 # pylint: disable=too-many-instance-attributes, too-few-public-methods
@@ -33,45 +31,82 @@ class Marktlokation(Geschaeftsobjekt):
     Object containing information about a Marktlokation
     """
 
-    # pylint: disable=unused-argument, no-self-use
-    def _validate_marktlokations_id(self, marktlokations_id_attribute, value):
-        if not value:
-            raise ValueError("The marktlokations_id must not be empty.")
-        if not _malo_id_pattern.match(value):
-            raise ValueError(f"The marktlokations_id '{value}' does not match {_malo_id_pattern.pattern}")
-        expected_checksum = Marktlokation._get_checksum(value)
-        actual_checksum = value[10:11]
-        if expected_checksum != actual_checksum:
-            # pylint: disable=line-too-long
-            raise ValueError(
-                f"The marktlokations_id '{value}' has checksum '{actual_checksum}' but '{expected_checksum}' was expected."
-            )
-
     # required attributes
     bo_typ: BoTyp = attr.ib(default=BoTyp.MARKTLOKATION)
-    marktlokations_id: str = attr.ib(validator=_validate_marktlokations_id)
+    #: Identifikationsnummer einer Marktlokation, an der Energie entweder verbraucht, oder erzeugt wird.
+    marktlokations_id: str = attr.ib(validator=validate_marktlokations_id)
+    #: Sparte der Marktlokation, z.B. Gas oder Strom
     sparte: Sparte
+    #: Kennzeichnung, ob Energie eingespeist oder entnommen (ausgespeist) wird
     energierichtung: Energierichtung
+    #: Die Bilanzierungsmethode, RLM oder SLP
     bilanzierungsmethode: Bilanzierungsmethode
     netzebene: Netzebene
+    """
+    Netzebene, in der der Bezug der Energie erfolgt.
+    Bei Strom Spannungsebene der Lieferung, bei Gas Druckstufe.
+    Beispiel Strom: Niederspannung Beispiel Gas: Niederdruck.
+    """
 
     # optional attributes
+    #: Verbrauchsart der Marktlokation.
     verbrauchsart: Verbrauchsart = attr.ib(default=None)
+    #: Gibt an, ob es sich um eine unterbrechbare Belieferung handelt
     unterbrechbar: bool = attr.ib(default=None)
+    #: Codenummer des Netzbetreibers, an dessen Netz diese Marktlokation angeschlossen ist.
     netzbetreibercodenr: str = attr.ib(default=None)
+    #: Typ des Netzgebietes, z.B. Verteilnetz
     gebietstyp: Gebiettyp = attr.ib(default=None)
-    netzgebietsnr: str = attr.ib(default=None)
+    #: Die ID des Gebietes in der ene't-Datenbank
+    netzgebietsnr: str = attr.ib(default=None)  # todo: rename to "id" (see 2021-12-15 update)
+    #: Bilanzierungsgebiet, dem das Netzgebiet zugeordnet ist - im Falle eines Strom Netzes
     bilanzierungsgebiet: str = attr.ib(default=None)
+    #: Codenummer des Grundversorgers, der für diese Marktlokation zuständig ist
     grundversorgercodenr: str = attr.ib(default=None)
+    #: Die Gasqualität in diesem Netzgebiet. H-Gas oder L-Gas. Im Falle eines Gas-Netzes
     gasqualitaet: Gasqualitaet = attr.ib(default=None)
+    #: Geschäftspartner, dem diese Marktlokation gehört
     endkunde: Geschaeftspartner = attr.ib(default=None)
-    zugehoerige_messlokation: Messlokationszuordnung = attr.ib(default=None)
+    zugehoerige_messlokation: Messlokationszuordnung = attr.ib(default=None)  # todo: rename to plural
+    """
+    Aufzählung der Messlokationen, die zu dieser Marktlokation gehören.
+    Es können 3 verschiedene Konstrukte auftreten:
+
+    Beziehung 1 : 0 : Hier handelt es sich um Pauschalanlagen ohne Messung. D.h. die Verbrauchsdaten sind direkt über
+    die Marktlokation abgreifbar.
+    Beziehung 1 : 1 : Das ist die Standard-Beziehung für die meisten Fälle. In diesem Fall gibt es zu einer
+    Marktlokation genau eine Messlokation.
+    Beziehung 1 : N : Hier liegt beispielsweise eine Untermessung vor. Der Verbrauch einer Marklokation berechnet sich
+    hier aus mehreren Messungen.
+
+    Es gibt praktisch auch noch die Beziehung N : 1, beispielsweise bei einer Zweirichtungsmessung bei der durch eine
+    Messeinrichtung die Messung sowohl für die Einspreiseseite als auch für die Aussspeiseseite erfolgt.
+    Da Abrechnung und Bilanzierung jedoch für beide Marktlokationen getrennt erfolgt, werden nie beide Marktlokationen
+    gemeinsam betrachtet. Daher lässt sich dieses Konstrukt auf zwei 1:1-Beziehung zurückführen,
+    wobei die Messlokation in beiden Fällen die gleiche ist.
+
+    In den Zuordnungen sind ist die arithmetische Operation mit der der Verbrauch einer Messlokation zum Verbrauch einer
+    Marktlokation beitrögt mit aufgeführt.
+    Der Standard ist hier die Addition.
+    """
 
     # only one of the following three optional attributes can be set
+    #: Die Adresse, an der die Energie-Lieferung oder -Einspeisung erfolgt
     lokationsadresse: Adresse = attr.ib(default=None)
     geoadresse: Geokoordinaten = attr.ib(default=None)
+    """
+    Alternativ zu einer postalischen Adresse kann hier ein Ort mittels Geokoordinaten angegeben werden
+    (z.B. zur Identifikation von Sendemasten).
+    """
     katasterinformation: Katasteradresse = attr.ib(default=None)
+    """
+    Alternativ zu einer postalischen Adresse und Geokoordinaten kann hier eine Ortsangabe mittels Gemarkung und
+    Flurstück erfolgen.
+    """
 
+    # todo: add kundengruppe
+
+    # pylint:disable=unused-argument
     @lokationsadresse.validator
     @geoadresse.validator
     @katasterinformation.validator
@@ -86,31 +121,6 @@ class Marktlokation(Geschaeftsobjekt):
         if amount_of_given_address_infos != 1:
             raise ValueError("No or more than one address information is given.")
 
-    @staticmethod
-    def _get_checksum(malo_id: str) -> str:
-        """
-        Get the checksum of a marktlokations id.
-        a) Quersumme aller Ziffern in ungerader Position
-        b) Quersumme aller Ziffern auf gerader Position multipliziert mit 2
-        c) Summe von a) und b) d) Differenz von c) zum nächsten Vielfachen von 10 (ergibt sich hier 10, wird die
-           Prüfziffer 0 genommen
-        https://bdew-codes.de/Content/Files/MaLo/2017-04-28-BDEW-Anwendungshilfe-MaLo-ID_Version1.0_FINAL.PDF
-        :param self:
-        :return: the checksum as string
-        """
-        odd_checksum: int = 0
-        even_checksum: int = 0
-        # start counting at 1 to be consistent with the above description
-        # of "even" and "odd" but stop at tenth digit.
-        for i in range(1, 11):
-            digit = malo_id[i - 1 : i]
-            if i % 2 - 1 == 0:
-                odd_checksum += int(digit)
-            else:
-                even_checksum += 2 * int(digit)
-        result: int = (10 - ((even_checksum + odd_checksum) % 10)) % 10
-        return str(result)
-
 
 class MarktlokationSchema(GeschaeftsobjektSchema):
     """
@@ -123,7 +133,7 @@ class MarktlokationSchema(GeschaeftsobjektSchema):
     class_name = Marktlokation
 
     # required attributes
-    marktlokations_id = fields.Str()
+    marktlokations_id = fields.Str(data_key="marktlokationsId")
     sparte = EnumField(Sparte)
     energierichtung = EnumField(Energierichtung)
     bilanzierungsmethode = EnumField(Bilanzierungsmethode)
@@ -139,7 +149,9 @@ class MarktlokationSchema(GeschaeftsobjektSchema):
     grundversorgercodenr = fields.Str(load_default=None)
     gasqualitaet = EnumField(Gasqualitaet, load_default=None)
     endkunde = fields.Nested(GeschaeftspartnerSchema, load_default=None)
-    zugehoerige_messlokation = fields.List(fields.Nested(MesslokationszuordnungSchema), load_default=None)
+    zugehoerige_messlokation = fields.List(
+        fields.Nested(MesslokationszuordnungSchema), load_default=None, data_key="zugehoerigeMesslokation"
+    )
 
     # only one of the following three optional attributes can be set
     lokationsadresse = fields.Nested(AdresseSchema, load_default=None)
