@@ -6,15 +6,14 @@ and corresponding marshmallow schema for de-/serialization
 from decimal import Decimal
 
 import attr
-from marshmallow import fields, post_load
+from marshmallow import fields
 from marshmallow_enum import EnumField  # type:ignore[import]
 
 from bo4e.com.com import COM, COMSchema
-
-# pylint: disable=too-few-public-methods
 from bo4e.enum.waehrungscode import Waehrungscode
 
 
+# pylint: disable=too-few-public-methods
 @attr.s(auto_attribs=True, kw_only=True)
 class Betrag(COM):
     """
@@ -31,15 +30,10 @@ class Betrag(COM):
 
 class BetragSchema(COMSchema):
     """
-    Schema for de-/serialization of Betrag.
+    Schema for de-/serialization of Betrag
     """
 
+    class_name = Betrag
     # required attributes
     wert = fields.Decimal(as_string=True)
     waehrung = EnumField(Waehrungscode)
-
-    # pylint: disable=no-self-use, unused-argument
-    @post_load
-    def deserialize(self, data, **kwargs) -> Betrag:
-        """Deserialize JSON to Betrag object"""
-        return Betrag(**data)
