@@ -7,7 +7,7 @@ from decimal import Decimal
 from typing import List
 
 import attr
-from marshmallow import fields, post_load
+from marshmallow import fields
 from marshmallow_enum import EnumField  # type:ignore[import]
 
 from bo4e.com.com import COM, COMSchema
@@ -61,6 +61,7 @@ class EnergiemixSchema(COMSchema):
     Schema for de-/serialization of Energiemix.
     """
 
+    class_name = Energiemix
     # required attributes
     energiemixnummer = fields.Int()
     energieart = EnumField(Sparte)
@@ -70,15 +71,9 @@ class EnergiemixSchema(COMSchema):
 
     # optional attributes
     bemerkung = fields.Str(load_default=None)
-    co2_emission = fields.Decimal(load_default=None, as_string=True)
+    co2_emission = fields.Decimal(load_default=None, as_string=True, data_key="co2Emission")
     atommuell = fields.Decimal(load_default=None, as_string=True)
     oekozertifikate = fields.List(EnumField(Oekozertifikat), load_default=None)
     oekolabel = fields.List(EnumField(Oekolabel), load_default=None)
-    oeko_top_ten = fields.Bool(load_default=None)
+    oeko_top_ten = fields.Bool(load_default=None, data_key="oekoTopTen")
     website = fields.Str(load_default=None)
-
-    # pylint: disable=no-self-use, unused-argument
-    @post_load
-    def deserialize(self, data, **kwargs) -> Energiemix:
-        """Deserialize JSON to Energiemix object"""
-        return Energiemix(**data)
