@@ -4,16 +4,14 @@ Contains Geraeteeigenschaften and corresponding marshmallow schema for de-/seria
 from typing import Optional
 
 import attr
-from marshmallow import post_load
 from marshmallow_enum import EnumField  # type:ignore[import]
 
 from bo4e.com.com import COM, COMSchema
-
-# pylint: disable=too-few-public-methods
 from bo4e.enum.geraetemerkmal import Geraetemerkmal
 from bo4e.enum.geraetetyp import Geraetetyp
 
 
+# pylint: disable=too-few-public-methods
 @attr.s(auto_attribs=True, kw_only=True)
 class Geraeteeigenschaften(COM):
     """
@@ -36,14 +34,9 @@ class GeraeteeigenschaftenSchema(COMSchema):
     Schema for de-/serialization of Geraeteeigenschaften
     """
 
+    class_name = Geraeteeigenschaften
     # required attributes
     geraetetyp = EnumField(Geraetetyp)
 
     # optional attributes
     geraetemerkmal = EnumField(Geraetemerkmal, allow_none=True)
-
-    # pylint: disable=no-self-use, unused-argument
-    @post_load
-    def deserialize(self, data, **kwargs) -> Geraeteeigenschaften:
-        """Deserialize JSON to Geraeteeigenschaften object"""
-        return Geraeteeigenschaften(**data)
