@@ -3,7 +3,7 @@ Contains Katasteradresse class
 and corresponding marshmallow schema for de-/serialization
 """
 import attr
-from marshmallow import fields, post_load
+from marshmallow import fields
 
 from bo4e.com.com import COM, COMSchema
 
@@ -24,11 +24,6 @@ class KatasteradresseSchema(COMSchema):
     Schema for de-/serialization of Katasteradresse.
     """
 
-    gemarkung_flur = fields.Str()
+    class_name = Katasteradresse
+    gemarkung_flur = fields.Str(data_key="gemarkungFlur")
     flurstueck = fields.Str()
-
-    # pylint: disable=no-self-use, unused-argument
-    @post_load
-    def deserialize(self, data, **kwargs) -> Katasteradresse:
-        """Deserialize JSON to Katasteradresse object"""
-        return Katasteradresse(**data)
