@@ -4,7 +4,7 @@ and corresponding marshmallow schema for de-/serialization
 """
 
 import attr
-from marshmallow import fields, post_load
+from marshmallow import fields
 from marshmallow_enum import EnumField  # type:ignore[import]
 
 from bo4e.com.com import COM, COMSchema
@@ -31,12 +31,7 @@ class KriteriumWertSchema(COMSchema):
     Schema for de-/serialization of KriteriumWert.
     """
 
+    class_name = KriteriumWert
     # required attributes
     kriterium = EnumField(Tarifregionskriterium)
     wert = fields.Str()
-
-    # pylint: disable=no-self-use, unused-argument
-    @post_load
-    def deserialize(self, data, **kwargs) -> KriteriumWert:
-        """Deserialize JSON to KriteriumWert object"""
-        return KriteriumWert(**data)
