@@ -1,10 +1,9 @@
 """
-Contains Rufnummer class
-and corresponding marshmallow schema for de-/serialization
+Contains Rufnummer class and corresponding marshmallow schema for de-/serialization
 """
 
 import attr
-from marshmallow import fields, post_load
+from marshmallow import fields
 from marshmallow_enum import EnumField  # type:ignore[import]
 
 from bo4e.com.com import COM, COMSchema
@@ -28,12 +27,7 @@ class RufnummerSchema(COMSchema):
     Schema for de-/serialization of Rufnummer.
     """
 
+    class_name = Rufnummer
     # required attributes
     nummerntyp = EnumField(Rufnummernart)
     rufnummer = fields.Str()
-
-    # pylint: disable=no-self-use, unused-argument
-    @post_load
-    def deserialize(self, data, **kwargs) -> Rufnummer:
-        """Deserialize JSON to Rufnummer object"""
-        return Rufnummer(**data)
