@@ -3,7 +3,7 @@ Contains Zeitintervall class
 and corresponding marshmallow schema for de-/serialization
 """
 import attr
-from marshmallow import fields, post_load
+from marshmallow import fields
 from marshmallow_enum import EnumField  # type:ignore[import]
 
 from bo4e.com.com import COM, COMSchema
@@ -28,12 +28,7 @@ class ZeitintervallSchema(COMSchema):
     Schema for de-/serialization of Zeitintervall.
     """
 
+    class_name = Zeitintervall
     # required attributes
     wert = fields.Integer()
     zeiteinheit = EnumField(Zeiteinheit)
-
-    # pylint: disable=no-self-use, unused-argument
-    @post_load
-    def deserialize(self, data, **kwargs) -> Zeitintervall:
-        """Deserialize JSON to Zeitintervall object"""
-        return Zeitintervall(**data)
