@@ -1,6 +1,7 @@
-import pytest
 from decimal import Decimal
 
+import pytest  # type:ignore[import]
+
 from bo4e.com.geokoordinaten import Geokoordinaten, GeokoordinatenSchema
 
 
@@ -26,7 +27,6 @@ class TestGeokoordinaten:
 
     def test_wrong_datatype(self):
         with pytest.raises(TypeError) as excinfo:
-
             _ = Geokoordinaten(breitengrad="54,23", laengengrad=-23.2)
 
         assert "breitengrad" in str(excinfo.value)
